@@ -192,22 +192,6 @@ def analyze_distance_betwee_strokes(raw_datasets,
     write_file.close()
 
 
-def get_aspect_ratio(raw_datasets):
-    """For each symbol: sum up the length of all strokes."""
-    filename = "aspect_ratios.txt"
-    open(filename, 'w').close()  # Truncate the file
-    strokefile = open(filename, "a")
-    start_time = time.time()
-    aspect_ratio = features.AspectRatio()
-    for i, raw_dataset in enumerate(raw_datasets):
-        if i % 100 == 0 and i > 0:
-            utils.print_status(len(raw_datasets), i, start_time)
-        ink = aspect_ratio(raw_dataset['handwriting'])[0]
-        strokefile.write("%0.2f\n" % ink)
-    print("\r100%"+"\033[K\n")
-    strokefile.close()
-
-
 def get_bounding_box_distance(raw_datasets):
     """Get the distances between bounding boxes of strokes of a single symbol.
        Can only be applied to recordings with at least two strokes.
@@ -411,7 +395,7 @@ def main(handwriting_datasets_file):
     # logging.info("get_bounding_box_distance...")
     # get_bounding_box_distance(raw_datasets)
 
-    f = [(features.AspectRatio(), "aspect_ratio.csv"),
+    f = [(features.Aspect_ratio(), "aspect_ratio.csv"),
          (features.Re_curvature(1), "re_curvature.csv"),
          (features.Height(), "height.csv"),
          (features.Width(), "width.csv"),
