@@ -6,12 +6,12 @@
 Each algorithm works on the HandwrittenData class. They have to be applied like
 this:
 
- >> import data_multiplication as multiply
- >> a = HandwrittenData(...)
- >> multiplication_queue = [multiply.copy(10),
+ >>> import data_multiplication as multiply
+ >>> a = HandwrittenData(...)
+ >>> multiplication_queue = [multiply.copy(10),
                             mulitply.rotate(-30, 30, 5)
                             ]
- >> x = a.multiply(multiplication_queue)
+ >>> x = a.multiply(multiplication_queue)
 """
 
 import inspect
