@@ -6,14 +6,14 @@
 Each algorithm works on the HandwrittenData class. They have to be applied like
 this:
 
- >> import features
- >> a = HandwrittenData(...)
- >> feature_list = [features.Stroke_Count(), \
+ >>> import features
+ >>> a = HandwrittenData(...)
+ >>> feature_list = [features.Stroke_Count(), \
                     features.Constant_Point_Coordinates(lines=4, \
                                                         points_per_line=20, \
                                                         fill_empty_with=0)\
                     ]
- >> x = a.feature_extraction(feature_list)
+ >>> x = a.feature_extraction(feature_list)
 """
 
 import inspect
