@@ -15,9 +15,10 @@ import yaml
 # mine
 import utils
 import preprocessing
-import hwrt.HandwrittenData as HandwrittenData
+import HandwrittenData
 
 sys.modules['hwrt.HandwrittenData'] = HandwrittenData
+sys.modules['HandwrittenData'] = HandwrittenData
 
 
 def main(folder):
